---
title: "Quantum Social Entanglement"
authors: ["nikomas.md"]
---

Trying to ascertain the intentions of multiplicitous entities on the geopolitical stage can be disorienting. The news can feel like an opera being transmitted in all directions from everywhere; this country said this, that country performed operations here, these people claim this. Geopolitics is more confusing than ever, our language determines that we discuss Nations as if they are individuals, singular minded entities that make up the cast list of the show.
Almost a century ago, the collection of ideas typically known as Marxism started a kind of evolution. Marxism, as a set of theories regarding the systems and motions of capital, crises of production, and class and power relations, remains relevant today, but as a lens it has developed beyond recognition. In the first issue of Becoming (Issue Zero), we quoted Rosi Bradiotti in saying “we are not in the same capital as Marx”, who, in the lecture that phrase came from, stated that the more cutting edges of the inquiries and concerns of Marxism today, stem from the work of those such as Gilles Deleuze and Michel Foucault. If there was a need to quickly explain the purpose and the context of what Becoming magazine frequently refers to as “Critical Theory”, it is this,  the result of analyzing all of the above — class relations, motions of capital, crises of production — a deeply contextualized and highly scrutinized approach to criticizing the apparatuses that exist around us.
Without any discredit to the original texts, whatever “Capital” was, as seen and ascribed by Karl Marx, is not the capital of today, at least this is what contemporary critics think; we still orient our lives around capital, but capital has, as everything does, become [something else]. Quantum Economists like Achim Szepanski are in a better position to detail the precise nature of this entity around which we orient everything, but it is precisely the Quantum nature of the economy that causes ripples across the global stage, and help to build a more coherent image of the confusing geopolitical opera.

One fundamental principle that has emerged from Critical Theory, specifically through the work of the more memorable names like Deleuze, Guattari, Baudrilliard, Guy de Bord, Jameson, and so on, is that the reality humans exist within, the site of our agency and communication, is not something objective, but a composite assemblage of experiences that are guided by and which imitate the dominant or hegemonic ideology. Words like Capitalism and Logocentrism are easily listed off, and easy to have contempt for, but the reason why “isms” are so hard for critical theory to shake off, is because of the fundamental argument that capitalism, or logocentrism, is not just a “way of thinking” but a way of shaping the very reality we live in. Whatever objective reality we once believed in, now appears like an entangled mess of contradicting fields that are defined and shaped by a set of complex relationships to every other field. In other words, it is common to hear within critical theory circles that we truly live within the interiority of capitalism. It is a box that we are stuck in, and we have been stuck here for so long that we have forgotten that there was ever an outside, or that anything could be different at all; this effect can be short handed as capitalist realism.

At the heart of what Rosi Bradiotti may see in Deleuze that she does not see in Marx, is an appreciation for the subtlety of the discreet. Deleuze & Guattari’s “introduction to the antifascist life”, as Foucault put it, is a critique of those fundamental questions — the nature and motion of capital, class and power relations, crises of production — of the same stature as Marx, but brought to the cutting edge; Quantum Marxists. In this sense it would be hard to call Deleuze & Guattari Marxists, as they offer a new take on capital that marks a new chapter entirely. You could say we are now deleuzoguattarianists, yet, this may mark the first time where a metaphysics of the human experience is presented in such a way where there can be no application of an“ism”; we have moved beyond categorizable modes of analysis, unless it became something absurd like “discreet non-ismists”.

Within critical theory, as we call it, one of the most radical and exciting phases appears to be in motion, where the studies of Quantum materialists collide with the topics of critical theory, bringing new life to something that has been considered somewhat of a cold case for decades.
While the word Quantum itself is subject to a certain sense of hype, at the point of realizing that the world humans experience as mutual is contoured and figured by subjective cognitive processes and understanding, it becomes necessary to take seriously the idea that quantum principles are relevant to sociology and psychology, to human systems and natural systems. What we experience on the macro are ripples emerging from the micro, and critical theory has taken this moment to reorient itself around this groundbreaking change. It is a case of the “same ideas” being reinterpreted by someone of a different cultural epoch:

For example, it is easy to see how the Marxism of Adorno relates to the Newtonian era, awareness of the latest scientific models and data undoubtedly influence the way ideas are formed. Take, in this instance, Sadie Plant’s analysis of the role of the computer in Ada Lovelace’s understanding. Plant writes that exposure to the computer associated with Charles Babbage transformed Ada Lovelace’s perception of reality beyond recognition. In place of an absolute world, Lovelace understand reality as the result of immensely complex computations, where basic functions are arranged in such ways that larger phenomena occur, and those larger phenomena become functional in the building of even larger, even more complex phenomena. If simple boolean logic can become a computer, if Minecraft Redstone can be assembled into a 32-bit computer, then all of the complex realities around us can easily be understood to emerge out of tiny, simple formula.
So perhaps Walter Benjamin’s universally recognised work “In the age of Mechanical Reproduction” is just the result of someone else, someone different, someone new, using the framework of Marx to conduct critical inquiry from a new angle, one which revealed something new. Yet today, the likes of Benjamin and Adorno are criticized with treating class and power relations too absolutely, treating different groups and entities like an infinitely dense black box, bumping around the universe just as Newton’s model of the solar system.

The emergence of the Quantum understanding influenced the way in which people experienced reality, and people who experience reality in a way that is more influenced by Quantum materialism will have a different way of answering the same questions than Marxists and critical theorists have always been asking. Deleuze & Guattari’s work is amongst the first in its field to truly ask these questions in the context of quantum materialism. There are no black boxes, no fundamental elemental materials, no clear distinctions at all, within the new critical theory that emerges after D&G. We no longer need the matrix model to explain our experience of life as a box within a box, we have the model of quantum realism. The myriad plateaus they envisioned align so elegantly with quantum field theory; their vision of the emergence of desire through machines of specification aligns so elegantly with the visions of quantum bubbling; their principle model of the rhizome aligns so elegantly with quantum fluctuations; their visions of haecceities and assemblages align so elegantly with quantum entanglement. There was no true beginning to the collision between quantum materialism and critical theory, and it is not seriously suggested that this collision started with or was invented by Deleuze & Guattari, as the point is precisely that these new ideas emerge as evidence that the collision was already happening — Deleuze & Guattari simply signpost the acknowledgement of a potential interpretation of “the universe in all of its entirety” that had become possible due to the already existing entanglement between all of these ideas. They were the people with the necessary social privileges and education to be amongst the first to publish internationally some ideas that may have been lurking in the popular consciousness for generations.

What we can expect to follow is the further development of this entanglement between the principles of discretion and our study of consciousness, of social dynamics. As a way of bringing this back to the beginning, the confusion of the geopolitical stage can be better understood when viewing them as if they are complex quantum phenomena bubbling out of the interplay between fields.

As critics of Adorno make clear, such notions of the “upper class”, “the united states of america”, “we” and “they”, and so on, cannot be treated like physical entities in the way that Newton considered planets. Rather than individuated, singular objects, these entities are assemblages of multitudes of other entities which are themselves multitudes, and all interactions within each multitude is governed by quantum theory.  Take for example “the music industry”, in a classical Marxist framework, we might view “the music industry” as some kind of imposing self-contained entity against which we are opposed. We used to talk about the music industry as if it were one entity, but by the time the internet arrived, and the era of digital distribution and Soundcloud, we are all participating in the music industry — we all buy and sell music in a way that constantly reinforces all of the things we are against. There is a fraction of people who rightfully engage in various forms of civil disobedience that challenge copyright and centralized distribution topology, but even as musicians dream at night of playing on a big stage, they recreate the same image of the capitalist consumer-spectator. Not only are the “bad guys” not a singular opposing entity, the discernable affective presence of the “bad guys” flows through our very fingers, in every dream and every transaction. We are the bad guys.
If each person is many, as Deleuze & Guattari say, how many is the United States, in all of its people and institutions? The area on the map marked “USA” is just its sovereign territory, which more than ever seems like a Headquarters or Head Office. What America is extends far beyond the boundaries of the map; the “USA” is everywhere, not just in terms of embassies, expats, exports, economy and military, but in terms of the total affective presence or “sphere of influence” it has on the global stage.  
Take for example a particularly important change in geopolitical history, the dissolution of the Soviet Union. Where the USA had forged many alliances with nations around the globe under the shared goal of opposing the Soviet Union, and through doing so had forged a large sphere of influence, there was no unifying meaning to this sphere of influence once the USSR collapsed. US affective presence was just there, for no real reason, and that presence collided with the new post-Soviet context it now existed in. Conveniently, the geopolitics of the post-cold war era is often discussed in terms of “entanglement theory”, due to how intertwined supposedly separate entities are. It has been over 30 years since the USSR ended, and the USA hasn’t been able to get out, the multiplicitous assemblage is permanently entangled with all of the other complex assemblages. The people and institutions are entangled with it all, and interactions between the larger assemblages send ripples down to the lower levels, and ripples are sent back up.
In place of a planetary entity, we end up seeing the USA, when viewed as an actor on the geopolitical stage, as an affective presence that bubbles in infinitely complex ways. It exists everywhere and nowhere, in relative amounts, and this existence materializes in and out rapidly in a way that can only be compared to Quantum fluctuations. The USA, as well as every other “nation”, every other massive assemblage of people and institutions, is more like a field, with a uniquely distributed mass and sphere of influence, colliding with infinite other fields, rippling and bubbling chaotically. Precisely because the USA is composite, its exact form and make up changes as rapidly as the minds of the millions that make it up. Now more than ever does the geopolitical stage seem like the interplay of thousands of plateaus that influence each other and respond to each other, and due to this constant movement, never cease becoming something else.

Quantum politics is experienced in the TV show “The Thick of It”. There was a special episode which followed the events of a single night in English party politics. A small rumour that the Prime Minister may resign caused a wave of insane political activity, where the politicians and MPs of one party are seen scurrying around London, forming cabals which then conflicted and collapsed in on themselves. In the presence of the potential power vacuum, chaos ensued, and any alliance or connection that was once maintained dissolved instantly. By the end of the night, it is found out that the rumour wasn’t true, and everyone immediately had to reset and continue on as if the entire night of warfare hadn’t happened. Imagine this but on the geopolitical stage, where, at all times, this nonsensical, absurd and ravenous madness goes on behind the surface, yet on the surface, to the public, it appears stable. It seems that we are entering into an era where a human can be seen as an infinitely complex wave function, or embodied chaos constantly collapsing in on itself. What we see as another human may seem self-contained and predictable, but beneath the surface it is a quantum assemblage — surprising behavior should come as no surprise.
