---
title: "On Non (Part I): Non-Music, (N)Ontology, and Distinguishing Bubbles"
authors: ["nikomas.md"]
keywords: ["Non", "non-musicology", "non-philosophy", "musicology", "deleuze & guattari", "haecceities", "process ontology", "music", "music philosophy", "Sociology of music", "Desire"]

---

It is important to remember from the offset that ‘non’ is not identical to ‘anti’ or ‘counter’, for example, ‘non-philosophy’ is not an ‘anti-philosophy’ in the sense of Badiou, although his work on Metapolitics [^1] is cited as influential in the formulation of non-philosophy [^2], neither a counter-philosophy or a rejection of philosophy. Non-philosophy is not philosophy in the traditional sense, but the specifics of “non-ness” are intricate, so it is not so simple as to say “doing philosophy differently”. The term directly interrogates philosophy as we know it, but with the intention of redeeming it, not abandoning it. Non seeks to dislodge a sense of rigidity with regards to all, or to dislodge matter from fixedness and move it towards indeterminacy, or to dislodge any totalising character from philosophy and hopefully equalize the field. In the context of this essay the term “non” specifically regards its use in the work of Francois Laruelle (as well as Deleuze & Guattari), who, in a book about non in the context of photography states the following: “this word does not designate some new technique, but a new description and conception of the essence of photography and of the practice that arises within it.” [^3]

Philosophy is a matter of thought, so to understand the specifics of non we must understand a little about thought. For the sake of establishing the framework necessary to discuss non and thought, there are two rhizomic concepts in particular to assemble together: The Metaphysics of Presence and Capitalist Realism. The two concepts are, at the minimum, useful in opening up the discussion of capital-forms and non-philosophy.

Note: there is a lot of overlap in the next few pages with preceding essays, but it includes some revisions and is included here for the sake of keeping certain ideas in proximity, and for the sake of reiterating important ideas in as many contexts as possible.

Across multiple works, Jacques Derrida discusses what he called “The Metaphysics of Presence” [^4], and we can understand these ideas as the foundational framework to another important concept: logocentrism, or the biasing of particular forms of knowledge or particular modes of knowing. Essentially, within a Patriarchal Capitalistic society, it is argued that there are key metaphysical underpinnings that frame and inform all thought, and the perpetuation or continuous expansion of capital depends on maintaining one particular worldview: one of objects, separation, and binaries. So, in the case of lets say, masculinity and femininity, the worldview of capitalism (logocentric or positivistic binarism) forces masculinity and femininity into a position of separated hierarchical opposites, and it will do this ubiquitously across any field or subject: Positive/Negative, Dominant/Submissive, Active/Passive, Man/Woman, Us/Them, and so on. At the core of this the fundamental binary: Presence/Absence, where metaphysical presence and absence are isolated from each other, put into opposition and hierarchised in favor of presence, every other binary falls in line, with everything that represents Presence (Masculinity, Man, Positive, Dominant, Active) is judged as superior to anything that represents Absence (Femininity, Woman, Negative, Submissive, Passive).

These metaphysical assumptions or biases influence how we construct thought, and how we construct the notions of knowledge and truth. Yet, as Derrida intended to prove, all of these assumptions are unnecessary, and none of this falls in line with contemporary philosophical dialogue. Following queer postcapitalist dialogue, there need be no separation of masculine and feminine, and certainly no hierarchical relationship between the two, yet these problems have seeped down to a very deep level in human consciousness, which is precisely why it is such a difficult problem to solve. Even our language, the medium we use to explore philosophical thoughts, are biased in favor of capitalism, words like absence and presence seem to reinforce the separation of an integrated or unified spectrum. The most simple example of this would be to remember that capitalism in part acts like a machine that generates needs and identities in order to create market demographics that can be sold to. Capital turns men and women into two distinctly separate categories that can be sold identities and needs as a demographic, that is one of the primary functions: treating men and women as part of an integrated spectrum would make marketing unnecessary commodities more difficult. So we have capitalism, and capitalism has a lot of these philosophical biases that are baked into the very words we use to think.

These predispositions built into our thought and our means to express thought become important, especially when discussing music, as music being ontologically absent means we lack the words to behold it and discuss it as it is. Ethnomusicologists in the naughties wrote extensively about how problematic the academic study of music had been for centuries, with music theory and musicology ending up in a strange category by itself, and discussed in terms of quite unhelpful and strange language (Semi-quavers? Mixollyidian?). Essentially, the wholly irrational nature of music meant that it resisted every attempt to be reduced to the capitalistic (logocentric, positivistic, objectivistic) mode of thought, so musicology drifted off into cultish obscurity until it was rightfully taken back by Sociologists and Anthropologists, who jested that despite centuries of dominance, classical musicologists, in their obsession with reducing sounds to visual patterns and graphs, appear to have never once actually used their ears to listen. Derrida directly accused Kant and his enlightened peers of bypassing the ear entirely in their engagement with music, due to the associations they made between the ear and negativity.

If we take the metaphysics of presence to a more radical end, this latent binarism feeds into notions of “us” and “them”, in-groups and out-groups; the fundamentals of racism are established upon this hierarchical binarism. We cannot conceive of a fluid or non-hierarchical notion of the human while we build our understanding or knowledge on top of a metaphysics of polarity.

A consequence of this inability to perceive fluid, rhizomic or multiplicitous forms, is that binarism takes control of social ordering and politics, even Thomas Nail discusses this in a podcast on [“Machinic Unconscious Happy Hour”](https://soundcloud.com/podcast-co-coopercherry/thomas-nail-marx-and-motion?si=5247d95d4e5146b398d66ed85b92d335&utm_source=clipboard&utm_medium=text&utm_campaign=social_sharing), claiming that capitalistic modes of thought forcibly takes a hold of subcultures, cultures, nations; any group in proximity is forced into binary oppositions with those surrounding them, creating conflict, competition and pressure.

Logocentrism has also fed into the arts in ways that have taken centuries to unpick. For example take the old Text/Context distinction, even though it is commonly understood now that what defines an object or text is its relationship to its context, capitalist modes of thought kept people believing that the artwork physically contained its meanings like an objective cipher that had nothing to do with its framing. As we know, labeling a painting differently can change our experience of it, or the placement of an artwork in different places can impact how it is experienced; context informs text, they are ontologically linked.

As has already been established, the consequences of the metaphysics of presence are not limited to music or art criticism, indeed all of Western culture is tainted by “phallogocentric-patriarchy”, the pervasive bias affecting all value and truth judgements, about how we see ourselves and the Self as distinct from each other and The Other; we separate ourselves from the universe as if we are Newtonian autonomous bodies:

 “We live under the illusion of a disembodied and universal cogito: a masculine subject, disguised as a neuter, upon which subjectivity is crafted and which consequently defines woman as negation and lack” — F. Söderbäck (2013) Being in the Present: Derrida and Irigaray. pp.258 [^5]

To conclude on this line of thought, through Derrida’s examination of this, we are presented with the image of thought as corrupted by pervasive ideologies. If our thoughts and language are suspect, how can we think or do anything exterior to those confines?

In a similar way to Derrida’s metaphysics of presence, Capitalist Realism presents reality as corrupted by the illusions of capital. As contemporary critics of Capitalism assert, Capitalism is not just a set of principles that govern an economy, it is an ideology that governs how we understand everything around us and how we should act. Given that Deleuze & Guattari have referred to Capitalism as a dark potentiality that has always existed, we can see Capitalism as being defined by applying the logic of capital-centric economics to all areas of life. Capitalism, its ideology and culture has territorialized everything. The consequence of this is that it has become difficult to negate Capitalism, or to distinguish what is not Capitalism from what is Capitalism.

One example relevant to music is the discussion of [Kurt Cobain](https://www.youtube.com/watch?v=6QYLteSfJlE), who is described as someone protesting MTV on MTV. While Cobain was acutely aware of this, which is the deepest part of the tragedy, he is presented or experienced as this tragic character who doesn’t realize that he is benefitting the very music industry he is protesting. The image of this oblivious or helpless protestor is how we all are under Capitalist Realism, either unaware that we participate in our own demise, or aware of it and unable to do anything about it, unable to understand if what we are doing is genuine praxis or just reiterating Capitalism. This notion of territorialisation has to be seen as an active and on-going process, where all that threatens or negates the dominant hegemony is eradicated or hidden from view. Another example is rave culture, which in the offset was radically anti-capitalist, but most of what remains today is highly consumeristic club culture and a tiny margin of risky, micro-raves. It is difficult to say exactly when rave culture was absorbed into the infinite plasticity of capitalism, this territorialisation process creeps in like mist.

With regard to deterritorialization, then, non- primarily concerns itself with confronting the capital-form, which we can now understand as a version of something after it has been successfully appropriated into Capital. What we experience of rave culture, for example, is now the capital-form of rave, the version of rave that has been allowed to sustain after all of its anti-hegemonic elements have been stripped away and neutralized. Capital-forms are clean-copies of everything, ideologically sanitized versions of anything and everything.

What Fisher describes mirrors Derrida as both present a situation in which everything we think or do is already accounted for, our words and linguistics prevent even discussing the exteriority of capitalism. Indeed, one critic of Francois Laruelle’s non-philosophy, Jacob Vangeest, is preoccupied with this problem in particular. If there really is no exterior to capital, where is non-capital, or non-philosophy supposed to exist? Perhaps an answer to this is to rephrase some of what Fisher said: Capital is not everything, it has just pervaded all the necessary areas to convince us absolutely that it is everything. In the infinite universe that expands into itself, there is an infinite amount of non-capital territory, and when thinking about it like this, the problem of capitalist realism starts to seem like a matter of finding a corner, finding a glitch, where capital reveals itself, and the illusion might be peeled off like a thin plastic film.

So the reality described by logocentrism and capitalist realism, is not one of lacking-exteriority, but with that exteriority hidden from sight. Saying that it is impossible to confront the complex and multiplicitous tensions that arise within the excess of capital is different to saying it is possible but we just don’t know how to do it.  


At this stage we can simply understand that Non seeks to dislodge a rigidity of form ; to dislodge matter from fixedness and move it towards indeterminacy; to dislodge any totalising character from philosophy and thus equalize the field.

To Deleuze & Guattari, Ontology has always been a creative task not a task of discovery; there has never been an Ontological discovery, only a history of creative production of Ontological frameworks to help the people understand the truly ungraspable chaos that we exist amongst. None of these philosophers of History were right, and neither did anyone really “improve” on another, as if Descartes, Hume, Kant and so on, were all part of a grand relay race towards truth. If then, the purpose of philosophy is not, and has never been, to pursue truth, then it opens up philosophy to a wide range of possible purposes. The philosophers of history can be valued and taken seriously as reference points into different sets of questions and different sets of theories being used to make sense of chaos at different times and places. The history of philosophy, no matter how much it resembles people wandering around a haunted forest at night, has left a bed of clues that can be excavated to gain new perspectives on this rhizomatic chaos we are all hopelessly trying to make sense of. It is not just a compendium of grand fictional stories, but a figurative motherlode of ideas to mine.

Practices of interpretation and meaning have been divided into varying categories over time, usually the Arts, Science, and Philosophy ([“Chaoids”](https://www.youtube.com/watch?v=bqV1uXy0Ny8)), all of which can describe any event in exceptional detail, but in completely different ways. The Artist may describe the human experience of the sun, in an emotional sense, sensational and subjective; the Scientist can conduct immense measurements and discuss things in terms of photons and chemistry. What has historically been less clear is what Philosophy offers, but when seen as a creative act, Philosophy can be understood as something vital to Science, being the mode of creating the very concepts which Science and Art engages with. Philosophy and philosophers ultimately carve the contours into our universe through what Deleuze & Guattari might have called pre-empirical investigation. The realm our being operates within is of such complexity and chaos that without Philosophy to carve sections out, Science could have no place to begin. That is the historical function of what has been considered philosophy until now, it has just taken until this time to be more clear about what it is that people have been doing all along; not chasing truth, but creating concepts and carving up the universe into something that Art and Science can explore further.

If that is a summary of the task of Philosophy, then what of non-philosophy, the supposed reincarnation of Philosophy once freed of the chains of truth. Deleuze & Guattari mention Francois Laruelle, in their text on the nature of philosophy, and regard the endeavor there as of the most interesting work being done today. Of the toughest challenges in coming to terms with non-philosophy is seeing the tensions and observing the subtle differences between the Philosophy of Deleuze & Guattari, and the non-philosophy of Laruelle.

For Laruelle, non-philosophy as described by Deleuze was still rooted in the philosophy it is rejecting; through recognising some autonomy of art and science, there is an implicit denial of that autonomy. For Laruelle, Deleuze still sees Philosophy as being in need of an “other”, either Science or Art, and has not yet unified them as one, whereas Laruelle explicitly seeks the unification of Science and Philosophy. At the crux of this, Laruelle feels Deleuze and Guattari’s conceptualisation of philosophy now still contains within it the separation of Philosophy and Art, one creating concepts, the other creating sensations. Perhaps Ashley Woodward puts it best, given their practiced articulation of Deleuze and Laruelle to art students: “Non-philosophy humbles philosophical materials, so that they may be thrown in the studio corner along with piles of fabric, lumps of plaster, and cans of paint, to be taken up with such things in the process of creative working.”

We begin to understand, if only rudimentarily, what the likes of Laruelle, Deleuze, and Derrida are examining through this deconstruction of philosophy. Derrida’s linguistics are a keen tool for unlocking the issues within this. When Laruelle states that “Philosophy is the capital-form of thought”, one interpretation draws parallels from Derridean analysis of language as containing within it hegemonic desire and ideology. Within the metaphysical assumptions of philosophy and language are the very hierarchies we seek to deconstruct, and we must be suspicious of the assumptions being made by our languages and our dialogues. Philosophy is not just philosophy in the view of Derrida, it is just a philosophy that has been moulded to capitalism and patriarchy. Philosophy in the West, for example, has more or less failed, for thousands of years, to have any way to grasp being or reality without the transcendental, without the divine other that contextualizes and negates the subject. When, historically, those have sought to remove the transcendental, they have, more often than not, been put to death as heretical. Here we see the Derridean critique more palpable. It is not just that Spinosa threatened or questioned the language or philosophy of the transcendental; the reason Spinoza was killed was precisely because of the undiscussed relationship between these points of language and the political and social hierarchies in place within society.

By necessitating the transcendental, one always rebuilds a hierarchy, reiterating authoritarian structures, structures of subjects falling under the transcendental. The transcendental is too preoccupied with the preservation of traditional dialectical understandings that ultimately serve to maintain a fictional natural order.  To exorcize philosophy of this transcendental is an imperative within the work of both Deleuze and Laruelle, to liberate philosophy from its obsession with maintaining the order of (hu)Man.

The question becomes how can you do philosophy without mistakenly reiterating the false natural order, or reiterating an implication of an indeed existing natural order. It is a particularly interesting time to think about Laruelle as it can converge with Rosi Bradiotti’s notions of making now the time of opening up our identity, there is a wondrous assemblage in the making here, where Deleuze and Laruelle collide with a posthumanism agenda of both opening up our notion of human or self, but also opening up our notions of philosophy, art and science as our means to order the chaos. The non-present moment that I experience long before you do, where past written meets future read, makes for safe grounds to guide machines into assemblages with other machines, to misunderstand and explore possibilities long rejected by those who themselves misunderstood the what of philosophy.


Non-music

Discussing definitions of music is known as the harmless drudge within Ethnomusicological circles. It is something of a burden, but being clear about the definition of music within any given publication is essential to (Ethno)musicological work, as the subject “Ethnomusicology” more or less exists because of a crisis of musical ontology. Ethnomusicology was once a shorthand for musicologists who were approaching the study of music from emerging new sociological and anthropological definitions of music. This was a different era though, and today the sociological take on music, the ‘ethno’ take, is almost ubiquitous; we are all just musicologists (again). Yet the chance is very high that anyone inducted into musicology in the last ten years is obsessed with musical ontology, and indeed musical ontology is the primary concern of a musicologist.  

Essentially, under late-stage capitalism everything is rendered or presented to us in forms that are specific to capital: music is almost entirely understood in the form of the commodity-spectacle because that is the form of capital. On the one hand, ‘music’ is the sound that comes out of that file or disk that you own, it comes out of the vinyl; it’s objectified and self-contained, it can be exchanged, bought or sold and functions as a commodity in being produced for the purpose of creating capital. On the other hand, music is something you can attend or witness, you can go and “see music”, a spectacle to behold, that you attend as an audience, no different from a cinema, whether it be a classical concerto, a musical opera, or a heavy metal concert. You buy your ticket, you position yourself as the consumer, and you eat it all up.

There are two, at least, major consequences of this way of understanding music, but nonetheless, music under capitalism is understood as some composite of these two concepts, existing in a very flat and surprisingly visual way (we go and “see” the band). These consequences are that we mistake the music for the object that contains it, or we mistake music for something that is given, to us, by performers on a stage, for that would make the audience but dumb recipients, impartial, uninvolved, bestowed upon by some other being presented as superior. The politics that emerge from both the commodification of music into digital trading cards and the spectacularization of musical performance are inherently hegemonic, they demand reality be participated in from a particular direction. In the case of the concert hall, the masses of stupid uninvolved listeners are blessed by glorious and righteous leaders, and all that can emerge from this is the politics of Ayn Rand, and the politics that have emerged from flattening music to a commodity-object is put concisely by Thomas Nail:

“We live in an age of objects. Today there are more objects and more kinds of objects than ever before in human history, and they continue to multiply at a mind-boggling rate. The sciences have succeeded in transforming almost every dimension of reality into one kind of object or another. They have mapped and cataloged nearly every corner of the earth. They have made commodities out of things that previous generations would never have thought to commodify, such as genetic codes, water, air, seeds and social care. Technological innovations now allow us to transcode almost anything into digital objects made of ones and zeroes. The scope of what constitutes an ‘object’ today seems to be unlimited. In this way, objects seem to have become synonymous with the nature of reality itself”  — Nail, T (2021) Theory of the Object. Edinburgh University Press [^6]

The excess of objects has pushed us towards an unquestionable belief in the objectivity of nature or the universe. So in an objective reality, music is also an object, but one that exists multiple times, in many mediums. Yet, music cannot be rendered in this objective view. An object must exist somewhere, but the location/source of the music, which in our case is CDs, digital files, vinyls, or even a band, we cannot say that the CD, the harddrive or the band is the song, rather all of them channel the song. In an object-oriented metaphysics the song must exist somewhere, and no source of the song can be mistaken for its objective location, after all, they’re channel copies of the song. The song is elsewhere.  

There is also the case of the “metaphysical individuation of songs” where analytical musicologists were stuck on the problem of each repetition of a song being different, taking on modulations that arise from the varying versions, performers, and sound-systems. Every repetition is different, and a positivistic or objective musical ontology cannot account for how a song’s most basic form is unstable, influx, evolving; it’s “quantum” and only a theory of motion, change, process or incompleteness can account for the ontological problems that has existed in musicology for a long time, and that ultimately caused the study of music to veer off into cult obscurity.

​​As we saw in previous parts with “logocentrism” and “capitalist realism”, we are simply conditioned to find such a thing as music hard to grasp. As Nietzsche wrote [^7], music terrorizes the rational with its absolute refusal to be reduced to image, and in a world of images, that one thing that cannot be flattened to an image must be seen as key to unravelling this flattened hyperreality we are in.

What is being pursued here, ultimately, is that a non-music must confront these issues, as the non- in non-music specifically refers to a resistance against the forms and limitations described until now. A non-music must resist objectification, it must resist spectacularization, it must try to resist commodification, for these are the pressures that push music into its capital-form.

Ironically, we are back at the beginning again, with a new need to define music in a new way, but this time it is the non-harmless drudge to define non-music. If music is not actually music, and music as we know it is just one potential form of music that is held into place, then what is music? It is unsurprising that given the relationship between non and capital, that the necessary foundation for non-music are the detractive critics of capital, namely Deleuze & Guattari, Laruelle, Bergson, Thomas Nail, and so on. Yet, the transition from music philosophy to non-music philosophy is really quite radical, and talking about music in such an alien way can be quite nauseating at first.

One definition of music that has been extremely useful over the years in researching ontology of music until eventually arriving at non-music comes from Kania & Gracyk. It is a useful definition because it appears, on the surface, perhaps the most concise way to define music in a way that does not depend upon fully unearthing everything down to the metaphysical level. This definition is not fully integrated into a metaphysics of process, but it is perhaps the closest you can get without going full-Deleuze.

Their definition is as follows: “Music is (1) any event intentionally produced or organized (2) to be heard, and (3) either (a) to have some basic musical feature, such as pitch or rhythm, or (b) to be listened to for such features.”  — [Andrew Kania & Theodore Gracyk (2011) Stanford Encyclopedia of Philosophy: Ontology of Music](https://plato.stanford.edu/entries/music/#MusiOnto). 

The first line of the definition states that music is an event, which recognises the non-objective form of music. Events are not objective, they are more like collisions, folds,  or alignments between objects or agents; they are temporal and experienced. Furthermore, it implies that music is about participation not reception, it is not received, it is participated in.  

The clauses (a) and (b) are included as a way of separating music from poetry, bird song, and, say, the sound emitted by a building site. These three are just some of the examples of situations which appear to encroach upon musical territory. Firstly, we consider poetry distinctly different to music, so music’s definition includes this notion of music-specific formal properties. Secondly, bird song contains what might appear to be musical properties, rhythm, melody and so on, but we do not experience them as music due to the sound not being organized with the intention of being heard as music, more or less a framing problem. We simply might not hear bird song as music because we assume it’s not supposed to be heard that way, then if we tried to listen to it as music, the absence of recognisable patterns or the absence of cultural references within the patterns and formations would make it hard to convince ourselves that it is worth following in that way. This also accounts for the building site, which is humans making noises in a way that might seem organized, happening in repetitive orders perhaps, but again does not seem to hold our attention when we try, as listeners, to make it into music.

This definition succeeds in recognising that the production or conception of musical events depend just as much on the listener as the performer or the source, instead of simply receiving an encoded sound, the listener proactively creates the event with the performer. Without the listener’s agency, without that culture of listening to music your favorite Bach melody would appear like a birdsong, just random pulses of sound, random fluctuations.   

The limitation of this definition, however, is that it presents a paradox. Music’s existence is predicated upon there being humans who understand what a musical feature is. In order for music to exist, it has to already exist in some form. Music has to be produced with the specific intention of making music, and without looking at this from the perspective of process ontology, it looks like an analog of the chicken/egg question. What came first, music or music?

So we can start by introducing one concept from Deleuze & Guattari’s ‘A Thousand Plateaus’ into the mix, namely the [“haecceity”](https://www.youtube.com/watch?v=77CMNYJEb4I&t=49s). A song, within a Deleuzoguttarian perspective, is a haecceity. It is a collision of fragments, the interfolding of mesh, that becomes something in of itself; multiple parts that, at least temporarily, assemble into something distinguishable or into an individuated something that can affect us. Haecceities bubble into existence, consequential to other movements, like a river curving upon itself until it collapses into an [oxbow lake](https://www.youtube.com/watch?v=nGJXxAZPm8M). The river produced the lake like a pot of boiling water produces bubbles. Or more specifically, the ebb and flow of the entire materiality of the rainforest-river-ecosystem produces the change, and when objects and ideas are conceptualized as being of the same meta-material, it radically transforms how we think about sociology. People’s behavior, the words that they speak, the way they organize into groups, is all happening through a similar process.

Haecceities “bubble out” of chaotic quantum materials when they twist and turn, and double-back on themselves, wrap around themselves, chokes itself, until something is cut off, or flung outwards, only to later collapse back into the chaos. Objects are bubbles, people are bubbles, songs are bubbles, and we can perhaps conceptualize the emergence of thoughts within a mind, or, say, what words actually emerge out of the mouth of the speaker, as bubbling out, like the oxbow lakes of the Amazon rainforest bubbles out of the river. Ultimately, the oxbow lake will eventually evaporate or change again, and disappear. It may take thousands of years but nonetheless it will eventually become something else, as everything is constantly becoming, moving, shifting, and the complex entanglement between all this motion produces haecceities (“things”).

While the notion of a bubbling-production in regards to the creation of music can make sense quite easily, the other side of the Kania & Gracyk’s definition that is being used as a basis is more complicated. The production of a musical bubble, a musical-haecceity, a song, is not just a random production, as the individuation of songs and the differentiation between songs and poetry for example (both inextricably human concepts) prove that within the interhuman (social) realm music is produced deliberately in contrast with any other human utterance or sounding. In other words, there are specific criteria involved in that production which, in order to be clearly distinguishable from other sonic-productions or soundings, depend on the listener being aware of that criteria. If the musician knew the criteria and the listener didn’t, there would likely be no musical haecceity established, the song or the music would not bubble out of the infinite pool, but remain indistinguishable. In terms of the framework proposed by Deleuze & Guattari, all that exists is born of this infinite pool of “desire”, everything that exists to us, in our reality, is a manifestation of this desire, but it manifests through specification. Until “a desire” is specific, or specified, it is indistinguishable from “desire”, so all that exists, all haecceities, are these specifications of desire: desire escapes itself through specification, so the importance of this specification of music cannot be understated. All haecceities are bubbles of desire separating from the indistinguishable, so the existence of the haecceity “music” is in this form, of a specified bubble that escapes “indistinguishable-ness” by eternally becoming-distinguishable.

[^1]: ![](bib:662cd225-6e82-47ca-a00e-651eeb54e3df)
[^2]: ![](bib:0cdfec90-d42b-4a3f-8f8a-6250c31472aa) p.ix
[^3]: ![](bib:4caace00-671a-4fe4-a92b-0ca498935048) p.4
[^4]: ![](bib:0fbe6684-af3c-4fa7-a8fc-c11ffa356573)
[^5]: ![](bib:9261c728-efd5-4f41-9b80-de9b0dfcf418)
[^6]: ![](bib:9e50d05d-bbce-4345-9c4c-bca0baa1eaa4)
[^7]: ![](bib:b898811c-8bf0-432f-85ed-ddeb2006a94d)
