---
title: "On the Death of Rave"
authors: ["nikomas.md"]
keywords: ["Hyperreal", "Neoliberalism", "Subculture", "Rave Culture", "Deleuze & Guattari", "Jeremy Gilbert", "Rave", "Music", "Music philosophy", "Sociology of music"]

---


# Part I: The event horizon

Today, nothing is what it seems to be. Part of this illusion perhaps includes the assumption that nothing was ever what it seemed to be. It is certainly interesting to challenge that assumption, as from within critical theory emerges the idea that we have, at least in the West, passed a certain dangerous threshold into a new epoch.

There is a phrase often associated with bitter middle-aged men: “things aren’t the same anymore”, especially in regard to subcultures like “Rave”, and such a position is infuriating enough to motivate an exploration of what exactly it is that is making that man complain.

Fundamentally, perhaps one of the biggest observable shifts regards what critical theory has started calling [“process ontology”](https://www.youtube.com/watch?v=lXhCsXcBdKI&t=16s) [^1], a new approach to metaphysics that emerges as early as Nietzsche [^2], leading all the way to Thomas Nail today, who appears to be standing forward as a new champion. Everything is always in flux; empty space is defined by [chaotic fluctuation and disorder](https://www.youtube.com/watch?v=J3xLuZNKhlY), in place of stillness or void; nothing ever stays the same indefinitely. This, however, does not really answer a specific question of what has changed in rave culture. It is clear that everything will and must change, everything is becoming everything else, always, but to answer the hypothetical old man’s question with “everything is in flux” is no different to answering the question with “entropy, dude”.

Ultimately, the question being asked is not “why did rave change?”, but “why did it change in this way?”. There is a certain need to let go, or to be open to letting change occur, to letting becomings flow, but just as a tragic death needs to be let go, a sensitive or dignified autopsy can teach us a lot about why the change happened this way. In this sense, it is important to be open to letting the rave go down the stream, but a sensitive autopsy of the death of rave may teach us a lot about the cause of that specific change. Rave could have changed in many other ways, it could have become much more, but instead it followed a path towards a form that, for the ravers, was no longer recognisable. So is the ravers lament; it’s not the same anymore. This essay unpacks what changed.

There are a number of specific changes that the West has passed through in the past half century, all of which seem to reflect a broader change in whatever cosmic winds drive the flow of culture. For Max Weber, there was a huge transition from what we can loosely call “traditionalism” to “modernism”, and the usual retelling of this transition revolves around Martin Luther and the Protestant reformations. In this shift, we see the decline in traditional orthodoxy (accepting the basic order of the universe as fixed) and a rise in Protestant Work Ethic, Rationalism, Bureaucracy, and social stratification [^3]. In essence, there was a transition from an era of understanding the universe in terms of fixedness and natural order, to an era of understanding the universe in terms of reflecting something, and being somewhat malleable. Rather than immense riches and success representing natural or inherited power, these riches became evidence of labor or pious living. Instead of a farmer simply farming, accepting the daily proceedings with some emotional distance, as everything is as it is meant to be, the farmer is now under pressure to maximize everything, as a humble living could now be interpreted as blasphemous, or would indicate sacrilegious living and would seem to indicate one’s fall from faith.

So much of what Weber seems to have observed revolves around the Enlightenment, a West-spanning movement that bridged Feudalism to Capitalism, that took society out of traditionalist orthodoxy and into modernity. This fairly long era is picked apart in great detail by Jacques Derrida [^4], and a lot of the observations and theories suggested by Derrida are discussed in the [first essays](cdcy.online/series/onraving1) published in this series. Amongst these ideas, or rather at the center of these ideas, is Derrida’s notion of Logocentrism, where the universe transforms in the subjectivities of the people due to a conditioning of the mind towards a specific set of truths. Where we end up is in a world where people are forced into seeing everything through one specific lens. We learned to see everything in binaries, and we learned to encode those binaries with social values and symbolism. Not only did we learn to see everything as Masculine or Feminine, we created a hierarchy, a power relation between the two poles. Everything that is reduced to Presence, Positivity or Masculinity, outranks everything that is reduced to Absence, Negativity or Femininity.

Derrida is relevant again here because what Max Weber described in previous centuries has happened again, and the West has very quickly passed over another threshold, one conveniently coinciding with the turn of the millennium. Derrida, amongst others like Deleuze & Guattari, were able to conduct such impressive analyses of the contemporary era, and the reality they describe is one that is radically different to what Weber observed. Where Marx was able to observe the machinations of capital in the 19th Century, the capital being observed in the 21st Century appears immensely different, and full of a different set of problems.

It is not that Deleuze & Guattari brought us into the new era with some heroic brilliance, neither is it the case that Marx ushered in a new era of thought, as both are cases where the cultural, social and economic change has already happened, and they are describing it as it passes through them. Just as that fundamental shift from traditionalism to modernism could be witnessed within the work of Marx, the shift from modernism to postmodernism is observed in the work of late 20th Century critical theorists like Deleuze & Guattari, Michel Foucault, and Derrida. As student of Deleuze and Foucault, [Rosi Bradiotti](https://www.youtube.com/watch?v=mb2_a-UX1OE&t=8s), states, we are no longer in the Capitalism of Marx, we are in a new Capitalism, one best understood through the work of Deleuze.

What is intended to be illustrated here, is the big shifts in how people perceive and understand reality around them, and how that understanding impacts the ways in which people act, how they engage with or resist power. It is slightly too unspecific to put a date on when these shifts happened, but the shift from modernism to postmodernism coincides with a large cultural shift that contains within it the rise and fall of rave culture. Therefore it is necessary to understand that rave culture flowed upon these broader cultural flows, that rave culture ascended and descended within and because of other cultural shifts, including major shifts such as how humans understand themselves and the universe around them. Rave changed because it existed through and of other waves of change.

The reality the west has entered or become, the Deleuzian version of capital that structures our lives and our economies, is expressed sorrowfully in the now infamous text “Capitalist Realism” [^5] by Mark Fisher. Fisher’s work is less philosophical than Deleuze & Guattari, but his understanding of critical theory allowed him to present a text that captures the state of the world now in quite an emotional way. After all, another important part of understanding what changed with Rave culture is understanding what sociocultural and economic conditions define the current epoch.

Neoliberalism, Postmodernity, Late-Stage Capitalism. These kinds of terms are used to describe the current state of the global economy. This essay regards all of these kinds of terms as reflecting one essential feature: the passing over a threshold into what can best be described as Capitalist Realism in the sense that Fisher explicates in his text.

To put it bluntly, we are now tripping on capital. Where Fisher offers many illustrative metaphors for this, one that is missed is the idea of an acid trip. There is a transition between the state of mind at the moment of putting the tab under your tongue, and the state of mind you end up in 4 hours later. Acid trips are playfully related to airplane journeys, and once they take off, you are at the mercy of that journey until the end, you cannot turn back, undo, or get off early. Once you are tripping, the trip is everything, it pervades all corners of reality, it happens inside you, through you, outside of you, because of you, because of them, through them, inside them. It’s in your mind, it’s how you see things, it’s what you see. This is the state we are in with capital, now. It has become everything, it exists everywhere, and everything leads back to capital. This is the realism of capital, that it has overtaken our reality.

Where Karl Marx observed a corrosive capital eating away at everything from Bar to Church to University, Deleuze and Guattari were left to observe only the goop that remained, the nonsensical plasma which remained after centuries of deterritorialization and desacralisation. We are swimming around in black ink, drenched and stained and drowning. Furthermore, for so many people around the world, it has become a bad trip, the second half of the 20th Century had its moments but now the trip has become more intense, more pervasive, more demanding of attention, and it is rapidly becoming the most unimaginably catastrophic bad trip ever known. We are facing down so much peril that the trip has transformed into a nightmare. If we can go as far as to define neoliberalism by this state, we can observe numerous crises of neoliberalism across the past half century, and it is these crises which have transformed neoliberalism from the utopia envisioned in the “1937 Paris World’s Fair” into a living hell.

These crises include the death of the union, reflecting a larger loss of collective organisation. What Fisher calls hyper individualisation refers to the atomisation of society, the dissolving of social connections, the dissolving of any means of collective power — we are becoming trapped within our own subjectivities, completely alone. Isabel Lorey [^6] recognises one fatal byproduct of this individualisation, coining the term precarity to describe the way each individual has become uniquely oppressed, often making it hard for people to relate to each other. It forces people to get stuck in their own nightmare, totally preoccupied by their own unique set of crises.

One of the most substantial crises of Neoliberalism involves time and temporality itself. Much of Fisher’s work is dedicated to understanding this crisis, particularly across a series of lectures called [“All of this is temporary”](https://www.youtube.com/watch?v=deZgzw0YHQI&t=63s), [“No Time”](https://www.youtube.com/watch?v=8Bk0kkRPmjE&t=1533s), and [“The Slow Cancellation of the Future”](https://www.youtube.com/watch?v=aCgkLICTskQ&t=1620s). Fisher describes a receding of the dimension upon which progress occurs, where the future collapses as it becomes meaningless. In “No Time”, Fisher talks about the financial crisis of 2008, which saw the collapse of Greece. In some strangely beautiful irony the “birthplace of democracy” failed as a state, and has been resuscitated and kept alive by typical exploitative means. Fisher argues that this crash proved without a doubt that Neoliberalism does not work. It is a dead ideology. Yet, where in history dead or collapsed ideologies are usurped or swept out by other emergent ideologies, nothing has risen up to take the place of neoliberalism. The cadaver of Neoliberalism remains seated upon the throne.

What this ultimately suggests is that nothing is changing, and that while that body sits limp in the chair, nothing can change. To borrow a DJing term, we are stuck in emergency loop, and it appears there is no conceivable way of getting out of it without turning off the CD player all together, resulting in a loud bang and a disturbed dance floor. When people talk of a crisis of future, or a cancellation of the future, what they mean is that without any means or channel for change to occur through, the entire concept of “the future” becomes meaningless. What could “future” possibly mean without the idea of constant ongoing change? For this Fisher uses the analogy of being “marooned in the 20th Century”.

Simon Reynolds, a contemporary of Fisher, at around the same time published some work that compliments these ideas of a loss of future under the name “Retromania” [^7]. Reynolds essentially claims that we can observe a stagnation of ideas or newness within Popular music, with trends now focusing on either bringing back old styles, or a kind of commodity fetishism for obscure relics from the past: “everything is a remix”. He states multiple times that even music criticism now has become simply an exhaustive examination of influences, seemingly valuing a work based on its relationship with past movements more than invoking any sense of the “new” or any sense of future. There is always the lurking doubt as to whether we have simply run out of all possible combinations of notes and chord sequences, but this seems highly unlikely, and a look at Fisher’s complimentary work can explain why we would have turned our musical attention away from the future, and back towards our past; “we have become marooned in the 20th century”.

In terms of our direction we have U-turned, with our attention turning towards ourselves, our recent past, and nostalgia. However, it is not something so easily condemned, as the shift in focus has to be contextualized in the larger picture. The turn of the millennium almost seemed like the crisis threshold, the point at which the volcano transforms from a smoking cap to a fireball, the moment where our concerns about plastics and carbon dioxide turn into panic. By 2001, with the September 11th incident in New York, the West’s understanding of itself radically changed. Fisher posits that the way the West responded to September 11 was by becoming self-conscious and paranoid. To put it simply, when you have been convinced by your Government and national media that outside of your nation exist many enemies who are trying to destroy you, some anti-establishment angst may transform into defensive and paranoid nationalism, especially if you are amongst the poor working class who, through societal atomization, have become hyperindividualised; alone, paranoid, and bombarded with Vice News and Big Data, the politics of working class English devolved into far-right nationalism, with people not knowing what to believe..

As a final note, there is one other major shift that is worthy of mentioning, as it is very much an extension of the work published in previous essays regarding Derrida and logocentrism. Within the exploration of what the likes of Deleuze & Guattari, Thomas Nail and Derrida call “the Image”, there is a notion of “Face”. As Terranova writes, there is no Fascism without Face and what Neoliberalism learned from the ideologies that preceded it (essentially Fascism & Communism) is how to use Face as a technology of power. Without repeating previous work, where Derrida observes a centralizing of the eye as the only rational sense, Deleuze & Guattari often suggest that through the very means explored by Derrida, reality for those within Capitalist Realism has been reduced to ‘Image’, something only knowable through the rational senses, and only discernible through rationalist cognition. Like Image, Face involves symbolic surfaces, and a key feature of Neoliberalism is the Facade, where, for example, political parties position themselves as one thing, but practice something contrary. Without being able to explore this in depth here, part of the process of entering capitalist realism may involve the transition from Fascism’s use of Face to direct attention away from the dark machinations underneath, Neoliberalism uses Face to hide the reality that there is no longer any body, everything has completely dissolved. To behold the reality of neoliberal economics, and the amount of Fugazi and speculation involved, is terrifying. This can be understood as a crisis of redaction, and some of the potential calamities coming off of this can be seen with the latest version of [Dall-E 2](https://openai.com/dall-e-2/). The potential of this incredible text-to-image AI is that in 10 seconds one could create a realistic photograph or image of anything, based on any text prompt. The researchers quickly put a limit on the Dall-E 2 because it could easily be used to create incriminating or suggestive photographs or other kinds of images. When truth is only found in image, and any image can be fabricated instantly, meaning vanishes. Photoshop has created enough problems with misinformation, Dall-E 2 is another level entirely.

At the heart of Capital is pure emptiness; capital is nihil. It erodes and dissolves all connections and all meanings, and after so many centuries of corrosion nothing remains beneath the face. It returns to the idea of the dead body upon the throne; we still look up to capital as our God Emperor, but it has become so removed from us that we cannot see that the body is dead, and everything beneath the surface has disintegrated.  


# Part II: Raving over the cliff face

Now we have set the scene, we can begin deconstructing that original frustration that motivated this response. What happened to Rave as this event horizon was crossed, what specifically changed? While one of the main goals of the non-philosophy essay to which this essay precedes is to explore the notion of “non-minimalism”, given a critical examination of what either constitutes minimalism or what it pursues, as a way of completing this trail of thought there is a chance to explore something that on the surface seems quite contrary: Jungle. After all, Jungle is Massive, not Minimal, right?

[Jungle was the sound of the UK underground](https://www.youtube.com/watch?v=Thr8PUAQuag&t=440s), the urban youth, and a celebration of the black roots of Electronic music. Jungle was a mutation of rave culture with a special interest in bass frequencies, sound systems, break beats, and, in a way that connects it to part I of this essay, a crisis of future (an extinction). Where most of rave culture, in history, would likely have a sincere claim to some revolutionary essence, a sense of biopolitical activism, of collective organization, and a politics of resistance, particular authors like Simon Reynolds and Mark Fisher imply that Jungle was a form of rave which really embodied the struggle of the current epoch, particularly regarding the scale of capitalism and certain terrifying consequences of the expansion of capital into all areas and across all domains. What Fisher describes as the slow cancellation of the future is essentially a summary of what so many critical theorists had been hinting at for a long time; there was an emerging crisis of time itself, born of and indicative of,  a diminishing sense of progress, or sense of moving forward, manifesting as a stagnation of culture and politics.

If, as we have said in the previous part, this crisis comes as an event horizon, Jungle sits right on the precipice. It could even be said that Jungle happened during the event, a kind of manifestation of rave that exists within the moment of transition, when all structures are finally dissolved and rave collapses into the blackhole, resulting in the time-distorting chaos of Jungle. Jungle was rave being torn apart. A superform of rave capturing so precisely the essence of rave, as if it were all forms of rave compressed into one before collapsing in on itself. It embodied the struggle and the resistance, the intricacies and subtleties, and the profoundness of the aesthetics and what these aesthetic forms were created for. It is entirely apt that rave’s response to the end of its existence was to rave even harder than ever, so hard that the Criminal Justice Act in 1992 happened. Rave was wrapped up, checkmate, doomed to die, but it created such a disturbance in its death throes that the State was forced to proceed with a more direct assassination.

Jungle presents a dark, dystopian reality, juxtaposing chewed up samples of the forgotten past with cutting edge synthesis which was still new and exciting enough to offer the listener a true sense of moving into the future. Jungle is almost alone in its ability to double and halve its tempo without losing the flow. 140bpm appears like the ideal tempo for doing this, 70bpm (relative to popular music in the west being ‘tuned’ to 120bpm) is very slow but not so slow that it sounds silly or cannot carry a flow, and 140bpm is very fast but not so fast that it is simply redlining one’s sensory inputs. The distance between the two is massive, so when a 70bpm backbeat switches to 140bpm breaks, it is an experience of acceleration that is so fast that it exhilarates (but not so fast that one cannot savor every last detail of that huge shift in energy). One moment you are drifting gently into the future like a tiny boat on a huge ocean, the next moment the ocean collapses, and you are flung out of the world (and you yourself become a kind of meteorite). That feeling of the floor being removed from under you, from absolute stillness to chaotic fluctuation, represents the moment of crisis, the transition between a volcano in the distance and pyroclastic flows devouring a city. The way the rushes come in appear to be modeled on the event horizon itself, recreating the snapping change in intensities.

These romantic statements beckon for some elaboration. Given capital before the event horizon, before the total onset of capitalist realism, it was argued that much of what rave culture explored and represented was intrinsically anti-capitalist. Its revolutionary essence hinged on it contending with and putting pressure on power structures. There is a sense of deleuzoguattarian schizophrenia within a lot of underground subcultures that comprise rave or are tangential to it, which intends to say that rave culture tinkered with the boundaries it was contained within, and devised escape plans and experiments.

What is observed within Jungle, this dark but supercharged and potent form of rave, are numerous examples of how rave culture overall gained its reputation for tinkering with reality with intention of dismantling it. Again, many of what follows can be attributed to many different microcosms within the rave rhizome, Jungle just contains a lot of these points:

1. Cyborgism
2. Sampling & Copyright.
3. Labour/Recreation
4. Tripping and Listening

Starting with a quick one (1) Cyborgism; Jungle investigated and occupied a particular intersection between man and machine, just as Hip Hop and Dub had done, guiding people towards cyborgian relationships with machinery and computers. In her text “Zeroes + Ones” [^8], a text that explores, amongst other things, cyberfeminism, Sadie Plant, a contemporary of both Mark Fisher and Simon Reynolds, discusses the idea that Ada Lovelace’s proximity, exposure to and involvement in early computing technologies changed how she experienced the world, literally changing her ontological understanding of the world, and as a consequence, her understanding of herself as a Self. In turn, one can imagine the way turntablism changed the reality of Grandmaster Flash, who even describes himself as a human sampler; a becoming-cyborg par excellence.  Junglists, and their intimacy with, and mastery of, samplers, potentially had their viewpoints dramatically changed. Fisher stated that “[Jungle] breakbeats weren’t simply sampled and looped. Instead they were fine tuned and micro-engineered, with individual drum hits manipulated on the sampler.” It is to be argued that this relationship with engineering and sampling contributed to changes in how its listeners and producers and DJs perceive reality and themselves. If this is the case, one might be able to argue that engagement with Junglism is or was inherently anti-capitalist as engagement with the sounds and the machinery inevitably alters how someone sees reality, and as critical theory has explored for a century, capitalist hegemony depends on maintaining a very specific and strictly contained understanding of reality.

Moving onto  (2);  Sampling is a big topic but we can focus on two specific things: (a) distortion of time, and (b) distortion of ownership and origins. Jungle foregrounded the technique of sampling, with the practice being integral to the production of Jungle. While Jungle can seem very punk, it is actually a genre with exceptional production skills, and there may be very few pressings remaining that still attest to the high level of engineering that went into some Jungle tracks. Samplers allowed for the manipulation of individual elements, so each sound could be individually altered on the fly, capturing that sense of constant flux, with few sounds ever sounding exactly the same. Advanced sampling allowed for the new and the old to be juxtaposed, with anything from any recording in the past being up for grabs, as any material the Junglist could get their hands on can be put into the sampler, manipulated and deployed. This paired with the afro/futuristic elements contributed to the distortion of how we perceive the progression of time, with past, future and present all blurring into one stagnant chaotic moment, like all of human history rolled into one intense moment.  

Sampling as a practice can also be read as subversive in less abstract terms, as it battled with capital in the field of copyright. The use of samples was often found to be in violation with copyright laws and the notion of intellectual property. Both notions of copyright and intellectual property are machinations of capital, designed to help instate and maintain the specific worldview that supports capital. Perhaps one way of reading it is that copyright is designed to reinforce individualism, asserting the idea that what you create is your property, and not a public good. It is precisely intended to detract from another artists ability to make use of that material without the owner being the primary benefactor. It may be normalized now, but the whole concept of intellectual property to the Deleuzian anticapitalist is quite laughable.

An example of this is how we conceive of knowledge formation; do we own our own individual knowledge or do we collectively ascertain what we know, do we share knowledge/is knowledge formed through social dimensions? In the work of Deleuze & Guattari, it is argued that there can be no original source of knowledge, and that there is no true citation to anything; we know what others know, and we know because others know. We read, we collect knowledge, we experience, and all of those streams of inputs are assembled, we remix knowledge and never create it. Even when new data is obtained, it is crunched into the matrix of everything else we know and all other knowledge we have access to. This is an illusion of science, an illusion that is maintained by the privileging and hegemony of the object within the West, there is no objective truth to anything, only socialized and relativistic meaning, and therefore we cannot individualistically take credit for knowledge or as the source of knowledge.

There is nothing more frightening to a capitalist than the idea that they did not really enterprise their own lives, there is nothing scarier than the idea that they are not the authors of their own work and the makers of their own destiny. It is a point of anger because the ever-harder-to-deny reality that meaning and knowledge is a social product creates deep tensions within a hegemony of sovereign individuals, it is an argument that threatens to completely destroy the stability of “the West as we know it”; no wonder people are so willing to violently defend the prophets of Objectivist Enlightenment; Isaac Newton, Emanuelle Kant etc.

None of the text here is original, at least insofar as there is no original; what is happening in this text is the coercion of proximity between numerous ideas from numerous, lost, and unstable sources, an attempt to signify something through the arrangement of ideas that emerge out of what might be regrettably called the collective consciousness. As researchers, we excavate the work of others, and we assemble and collate the residual knowledge or understandings into long strips of text in hopes of stumbling across something that changes something else. If what we produce is original for someone, there is a strong chance that someone “possesses” knowledge that we do not, and therefore we are creating further unique assemblages of knowledge that go beyond or reveal something differently. This isn’t original knowledge, no knowledge is original, no art or creation is original in any sense that would support the idea of intellectual property. So copyright defends, above all, the concept of individual ownership, as a means of creating the necessary legal frameworks in which threats to individualism can be legally punished. Without a form of punishment for jeopardizing the illusion of individualism, and the illusion of individually earned and possessed knowledge, it would be much harder to maintain such a hegemony.

Jungle foregrounded a rather direct form of collectivist creation. No one can pretend anything is original when something is made out of scraps of other stuff, but you still get a chance to value and appreciate the skills of the assembler or engineer, without any illusion that somehow every aspect of this sound is disconnected to the ocean of music surrounding it. A lot of underground rave music is not produced for the purpose of generating money, they’re produced to be experienced, and its value comes from being experienced on a sound system, high as a kite. It is commonplace for producers to simply not care about illegal file sharing and people passing their purchases and downloads to their friends, as ultimately they want their track to be played out. It is not a production of commodities. Nonetheless it is these tensions that these practices created with capital that make a case for Jungle’s subversiveness.

Point number (3) is general for a lot of rave culture, but it is true of Jungle all the same. As Jeremy Gilbert explores [^9] in detail, rave culture challenged capitalistic conceptualisations of labor, given that rave culture and its do-it-together-soundsystem-culture often blurred the very sacred lines between labor/play. It’s taxless tickets, occupation of alternative spaces, and unaccounted sampling and remixing cultures contrasted harshly with capitalist values, the collectivism and mass-assembly of rave contrasted harshly with capitalistic individualism and thatcher-esque Neoliberalism, and the entire dialogue around tripping, ritualism, attentiveness, and drugs presented a new take on morality and spiritualism that “capitalism thought” it had eradicated with the Pagans who lived in the very fields ravers raved in. Rave had to go, it was simply a collection of protests against the conditions of neoliberal capitalism manifesting as a riotous music culture of the young masses, and to many critics, Jungle was the crown jewel. However, where rave culture subverted the sacred boundary between work and leisure which capitalism had once depended upon, communicative technologies have now too found a way to erase this boundary and usher in an era where people are always at work. That particular practice of subversion has been rendered obsolete.

(4), (5), and (6) are not necessary to cover in detail here as there are several works which elaborate on them in detail. With a glancing look however, (4) refers to the discussion of listening and tripping in []“On Raving 02&3”](https://cdcy.online/issue/onraving2/), where the act of “deep listening” [^10] is argued to negate or interrupt certain perceptual or cognitive processes that create limitations in how we construct ideas. It is argued that the rave facilitates an opportunity for tripping, and extended “deep listening” experiences which can radically alter how one forms ideas, concepts and knowledge in euphoric epiphanies.

There are also the clear afrofuturist tendencies in Junglists like Goldie’s work, as Ashley Clark highlights, envisioning futuristic spaces or imagined futures which comment on current urban realities, but it is so urgent, or desperate, or perhaps detached. If you listen to 1996 Jungle track “Deepness” by Electric Blue, the vibe and the feeling of the sound is as described. It seems so lost and bitter, but suddenly explodes into glorious light, as if hoping for some miraculous burst of light in the reality of the Junglist.


# Final remarks

Perhaps rather aptly, it is really after Jungle that rave seems to disappear, the turning point of the millennium started almost immediately with that immense plunge into the War on Terror after 9/11, and international politics devolved into 20 years of what we can now see as nothing but the sustained and miserable destruction of such places as Afghanistan, Libya, Iran, and so on. It is in this decade where all of the problems that today’s philosophical and critical dialogues concern seem to arise. Jihad, Social media, Prozac, Climate change, and all of Capitalism’s great triumphs seemed to blossom, with the decade finishing in what Fisher describes as the death of Neoliberalism around 2008 with debt crises and so on. At the end of this decade we are left with the corpse of Neoliberalism being re-elected time after time, in a situation which Fisher describes as an absence of an emergent alternative ideology. Everyone knows Neoliberalism is dead, it is fundamentally flawed and hated by all, but there is nothing to swoop in and take its place, so we simply stagnate. Fisher’s book Capitalist Realism was released in 2008, but by then capitalist realism was already eclipsing reality; capitalist realism was capitalist realism. Just as Jungle was both a reflection of that decay and a perpetuation of it, so was Fisher’s book; some find it hopeful, in a way that smacks of realism, but others see it, and Fisher’s eventual passing, as a confirmation of their deepest cynicism.  

All of these ideas reflect the title of this essay, the transition from real to hyperreal, from before capitalist realism to during it. It attempts to describe in simple terms the situation we have left, and the situation we have entered. This essay serves the purpose of introducing properly the next essay, entitled “On Non”, as it was felt that to move into non-philosophy all of this was necessary to explain. Non is the current direction of CDCY, deeply influenced by the work of Mille Plateaux and Achim Szepanski, Deleuze & Guattari, Fisher, Francois Laruelle and so on. It is a step we want to take together, to explore together, and the key to non-philosophy lies within the final comments of this essay. We cannot distinguish between capital and not-capital, we cannot negate it, that is what was explored in the idea of the acid trip, and capitalist realism. Everything looks like capital, everything has become capital, including philosophy. The neologism is accredited to Laruelle, but in essence non-philosophy involves asking what the capital-form of philosophy is, and what a non-(capital-form)philosophy might be. “Non-“ indicates a version of something that exists outside of capitalist realism, and does not contain the blueprints of capital at its core [^11].

[^1]: ![](bib:9e50d05d-bbce-4345-9c4c-bca0baa1eaa4)
[^2]: ![](bib:b898811c-8bf0-432f-85ed-ddeb2006a94d)
[^3]: ![](bib:b63eddf0-a5de-4b93-8a10-2ce36296b2ff)
[^4]: ![](bib:0fbe6684-af3c-4fa7-a8fc-c11ffa356573)
[^5]: ![](bib:31252706-d6f6-4492-bc65-3f25dd0774eb)
[^6]: ![](bib:583bf6d8-2b97-4ff0-8637-bf947aa5e564)
[^7]: ![](bib:c62f30c0-b32c-4e2e-a543-de12aba16deb)
[^8]: ![](bib:dbb3cbbc-7f20-419e-bf44-eb9be2a51059)
[^9]: ![](bib:9e03bfc5-50ef-48c0-8758-e2870f2d7c74)
[^10]: ![](bib:1803b6b4-1721-4ce6-adf6-663c7a84201c)
[^11]: ![](bib:02abd7da-7856-472a-8411-1805647d4d06) 

